@@ -367,7 +367,7 @@ class Experiment:
         return """
         SELECT
             e.client_id,
-            `moz-fx-data-shared-prod.udf.get_key`(e.event_map_values, 'branch')
+            `mozfun.map.get_key`(e.event_map_values, 'branch')
                 AS branch,
             min(e.submission_date) AS enrollment_date,
             count(e.submission_date) AS num_enrollment_events
@@ -623,6 +623,9 @@ class TimeLimits:
                 time_series_period
             ))
 
+        if num_dates_enrollment <= 0:
+            raise ValueError("Number of enrollment dates must be a positive number")
+
         analysis_window_length_dates = 1 if time_series_period == 'daily' else 7
 
         last_enrollment_date = add_days(
